summaryrefslogtreecommitdiffstats
path: root/net/http/http_stream_factory.h
diff options
context:
space:
mode:
Diffstat (limited to 'net/http/http_stream_factory.h')
-rw-r--r--net/http/http_stream_factory.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/net/http/http_stream_factory.h b/net/http/http_stream_factory.h
index e207a86..59956e1 100644
--- a/net/http/http_stream_factory.h
+++ b/net/http/http_stream_factory.h
@@ -33,7 +33,7 @@ namespace net {
class AuthCredentials;
class BoundNetLog;
-class BidirectionalStreamJob;
+class BidirectionalStreamImpl;
class HostMappingRules;
class HostPortPair;
class HttpAuthController;
@@ -92,10 +92,10 @@ class NET_EXPORT_PRIVATE HttpStreamRequest {
const ProxyInfo& used_proxy_info,
WebSocketHandshakeStreamBase* stream) = 0;
- virtual void OnBidirectionalStreamJobReady(
+ virtual void OnBidirectionalStreamImplReady(
const SSLConfig& used_ssl_config,
const ProxyInfo& used_proxy_info,
- BidirectionalStreamJob* stream) = 0;
+ BidirectionalStreamImpl* stream) = 0;
// This is the failure to create a stream case.
// |used_ssl_config| indicates the actual SSL configuration used for this
@@ -231,10 +231,10 @@ class NET_EXPORT HttpStreamFactory {
WebSocketHandshakeStreamBase::CreateHelper* create_helper,
const BoundNetLog& net_log) = 0;
// Request a BidirectionalStreamJob.
// Will call delegate->OnBidirectionalStreamJobReady on successful
// completion.
- virtual HttpStreamRequest* RequestBidirectionalStreamJob(
+ virtual HttpStreamRequest* RequestBidirectionalStreamImpl(
const HttpRequestInfo& info,
RequestPriority priority,
const SSLConfig& server_ssl_config,
@@ -231,10 +231,10 @@ class NET_EXPORT HttpStreamFactory {
WebSocketHandshakeStreamBase::CreateHelper* create_helper,
const BoundNetLog& net_log) = 0;
- // Request a BidirectionalStreamJob.
- // Will call delegate->OnBidirectionalStreamJobReady on successful
+ // Request a BidirectionalStreamImpl.
+ // Will call delegate->OnBidirectionalStreamImplReady on successful
// completion.